/*-- ================================================================== --
-- SISTEMA         : GESTAO DE VENDAS                                   --
-- DATA DA CRIAO : 18/06/2007                                         --
-- CRIAO         : FELIPE H.                                          --
-- OBJETIVOS       : INTEGRAAO DE CREDITOS DO SITE                     --
-- ==================================================================== --
*/

CREATE OR REPLACE
PROCEDURE INTEGRA_SITE_SDX(
   P_CDFILIAL      IN FILIAL.CDFILIAL%TYPE,
   P_CDIDCONSUMID  IN CONSUMIDOR.CDIDCONSUMID%TYPE,
   P_CDFAMILISALD  IN FAMILIASALDO.CDFAMILISALD%TYPE,
   P_DTMOVEXTCONS  IN EXTRATOCONS.DTMOVEXTCONS%TYPE,
   P_DSOPEEXTCONS  IN EXTRATOCONS.DSOPEEXTCONS%TYPE,
   P_VRMOVEXTCONS  IN EXTRATOCONS.VRMOVEXTCONS%TYPE,
   P_NRDEPOSICONS  IN EXTRATOCONS.NRDEPOSICONS%TYPE,
   P_RETORNO      OUT VARCHAR2)
AS
   V_NRSEQSITE     VARCHAR(50);
   V_CDCLIENTE     VARCHAR(21);
   V_CDCONSUMIDOR  VARCHAR(21);
   V_NRPEDCRECONS  VARCHAR(21);
   V_CDFILIAL      VARCHAR(04);
   V_CDFAMILISALD  VARCHAR(03);
   V_VRSALDCONFAM  FLOAT;
   V_DTPEDCRECONS  DATE;
BEGIN
   V_DTPEDCRECONS := TO_DATE(SYSDATE,'DD/MM/YY');
   P_RETORNO := '';
   
   -- VALIDA A FILIAL
   BEGIN
      SELECT CDFILIAL
      INTO V_CDFILIAL
      FROM FILIAL
      WHERE CDFILIAL = P_CDFILIAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        V_CDFILIAL := NULL;
   END;
   IF V_CDFILIAL IS NULL THEN
      P_RETORNO := 'FILIAL NAO ENCONTRADA';
      --RAISE_APPLICATION_ERROR(-20501, 'FILIAL NAO ENCONTRADA', True);
   END IF;

   -- VALIDA O CRACHA DO ALUNO
   BEGIN
      SELECT CDCLIENTE, CDCONSUMIDOR
      INTO V_CDCLIENTE, V_CDCONSUMIDOR
      FROM CONSUMIDOR
      WHERE CDIDCONSUMID = P_CDIDCONSUMID;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        V_CDCLIENTE := NULL;
   END;
   IF V_CDCLIENTE IS NULL THEN
      IF P_RETORNO IS NULL THEN
         P_RETORNO := 'CRACHA NAO ENCONTRADO';
      END IF;
      --RAISE_APPLICATION_ERROR(-20501, 'CRACHA NAO ENCONTRADO', TRUE);
   END IF;

   -- VALIDA SE O CRACHA DO ALUNO ESTA HABILITADO PARA A FILIAL
   BEGIN
      SELECT CO.CDCLIENTE, CO.CDCONSUMIDOR
      INTO V_CDCLIENTE, V_CDCONSUMIDOR
      FROM CONSUMIDOR CO, CLIENFILIAL CF
      WHERE CO.CDIDCONSUMID = P_CDIDCONSUMID
        AND CO.CDCLIENTE    = CF.CDCLIENTE
        AND CF.CDFILIAL     = P_CDFILIAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        V_CDCLIENTE := NULL;
   END;
   IF V_CDCLIENTE IS NULL THEN
      IF P_RETORNO IS NULL THEN
         P_RETORNO := 'CRACHA NAO HAB. PARA FILIAL';
      END IF;
      --RAISE_APPLICATION_ERROR(-20501, 'CRACHA NAO HAB. PARA FILIAL', TRUE);
   END IF;

   -- VALIDA O CODIGO DA FAMILIA
   BEGIN
      SELECT CDFAMILISALD
      INTO V_CDFAMILISALD
      FROM FAMILIASALDO
      WHERE  CDFAMILISALD = P_CDFAMILISALD;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        V_CDFAMILISALD := NULL;
   END;
   IF V_CDFAMILISALD IS NULL THEN
      IF P_RETORNO IS NULL THEN
         P_RETORNO := 'FAMILIA NAO ENCONTRADA';
      END IF;
      --RAISE_APPLICATION_ERROR(-20501, 'FAMILIA NAO ENCONTRADA', TRUE);
   END IF;

   -- VALIDA SE A FAMILIA FOI PARAMETRIZA PARA FILIAL
   BEGIN
      SELECT CDFAMILISALD
      INTO V_CDFAMILISALD
      FROM FAMSALDOFILI
      WHERE CDFAMILISALD = P_CDFAMILISALD
        AND CDFILIAL     = P_CDFILIAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        V_CDFAMILISALD := NULL;
   END;
   IF V_CDFAMILISALD IS NULL THEN
      IF P_RETORNO IS NULL THEN
         P_RETORNO := 'FAMILIA NAO PARAMETRIZADA PARA A FILIAL';
      END IF;
      ---RAISE_APPLICATION_ERROR(-20501, 'FAMILIA NAO PARAMETRIZADA PARA A FILIAL', TRUE);
   END IF;

   -- VALIDA SE A DATA FOI INFORMADA
   IF P_DTMOVEXTCONS IS NULL THEN
      IF P_RETORNO IS NULL THEN
         P_RETORNO := 'DATA DO MOVIMENTO DEVE SER INFORMADA';
      END IF;
      --RAISE_APPLICATION_ERROR(-20501, 'DATA DO MOVIMENTO DEVE SER INFORMADA', TRUE);
   END IF;

   -- VALIDA SE A DESCRIO FOI INFORMADA
   IF P_DSOPEEXTCONS IS NULL THEN
      IF P_RETORNO IS NULL THEN
         P_RETORNO := 'DESCRICAO DEVE SER INFORMADA';
      END IF;
      --RAISE_APPLICATION_ERROR(-20501, 'DESCRICAO DEVE SER INFORMADA', TRUE);
   END IF;

   -- VALOR DEVE SER MAIOR QUE ZERO
   IF P_VRMOVEXTCONS <= 0 THEN
      IF P_RETORNO IS NULL THEN
         P_RETORNO := 'VALOR DEVE SER MAIOR QUE ZERO';
      END IF;
      --RAISE_APPLICATION_ERROR(-20501, 'VALOR DEVE SER MAIOR QUE ZERO', TRUE);
   END IF;

   -- VALIDA SE NMERO DO DEPSITO FOI INFORMADO
   IF P_NRDEPOSICONS IS NULL THEN
      IF P_RETORNO IS NULL THEN
         P_RETORNO := SUBSTR('NUMERO DO DEPOSITO DEVE SER INFORMADO',1,50);
      END IF;
      --RAISE_APPLICATION_ERROR(-20501, 'NUMERO DO DEPOSITO DEVE SER INFORMADO', TRUE);
   END IF;

   IF P_RETORNO IS NULL THEN
      -- BUSCA O SALDO ATUAL DO ALUNO PARA A FAMILIA
      BEGIN
         SELECT VRSALDCONFAM
         INTO V_VRSALDCONFAM
         FROM SALDOCONS
         WHERE CDCLIENTE    = V_CDCLIENTE
           AND CDCONSUMIDOR = V_CDCONSUMIDOR
           AND CDFAMILISALD = V_CDFAMILISALD;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
           V_VRSALDCONFAM := NULL;
      END;
      IF V_VRSALDCONFAM IS NULL THEN
         V_VRSALDCONFAM := 0;
      END IF;

      NOVO_CODIGO ('PEDICREDCONS',V_NRPEDCRECONS);
      
      INSERT INTO PEDICREDCONS
         (NRPEDCRECONS,CDCLIENTE,CDCONSUMIDOR,DTPEDCRECONS,VRPEDCRECONS,DSSITCREBANC,IDPEDCREEXTR)
      VALUES
         (V_NRPEDCRECONS,V_CDCLIENTE,V_CDCONSUMIDOR,V_DTPEDCRECONS,P_VRMOVEXTCONS,'PROCEDURE SDX INTEGRA_SITE','S');

      INSERT INTO PEDICREDFAMI
         (NRPEDCRECONS,CDFAMILISALD,VRPEDCREFAMI)
      VALUES
         (V_NRPEDCRECONS,P_CDFAMILISALD,P_VRMOVEXTCONS);
         
      INSERT INTO EXTRATOCONS
        (CDCLIENTE,CDCONSUMIDOR,CDFAMILISALD,DTMOVEXTCONS,NRSEQMOVEXT,CDTIPORECE,
         CDFILIAL,CDCAIXA,NRSEQVENDA,DSOPEEXTCONS,VRMOVEXTCONS,VRSALDCONEXT,IDTPMOVEXT,
         DTABERCAIX,DTULTATUEXT,IDIMPEXTCONS,NRDEPOSICONS)
      VALUES
        (V_CDCLIENTE,V_CDCONSUMIDOR,P_CDFAMILISALD,P_DTMOVEXTCONS,'001','001',
         P_CDFILIAL,'','',SUBSTR(P_DSOPEEXTCONS,1,30),P_VRMOVEXTCONS,V_VRSALDCONFAM+P_VRMOVEXTCONS,'C',
         NULL,SYSDATE,'N',SUBSTR(P_NRDEPOSICONS,1,20));

      ATUALIZA_SALDO_CONS_FKB(V_CDFILIAL,V_CDCLIENTE,V_CDCONSUMIDOR,P_CDFAMILISALD);

      P_RETORNO := V_NRPEDCRECONS;
   END IF;
END;
/


-- VERSAO --
BEGIN ATUVEROBJ('INTEGRA_SITE_SDX','4.11.148'); END;
/

